#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-dns-z-dns-internal
version:              4.2.0
package-name:         dns
lib-name:             dns-internal
id:                   dns-4.2.0-A2aNY33DBaa2XhdZBWKfHv-dns-internal
key:                  dns-4.2.0-A2aNY33DBaa2XhdZBWKfHv-dns-internal
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  57bdb4441be90ed45726ce09f6ad11db
exposed-modules:
    Network.DNS.Base32Hex Network.DNS.Decode.Internal
    Network.DNS.Decode.Parsers Network.DNS.Encode.Builders
    Network.DNS.Encode.Internal Network.DNS.Imports Network.DNS.Memo
    Network.DNS.Resolver.Internal Network.DNS.StateBinary
    Network.DNS.Types.Internal Network.DNS.Types.Resolver

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.2.0-A2aNY33DBaa2XhdZBWKfHv-dns-internal
depends:
    array-0.5.6.0 async-2.2.5-G9iNhoihA4w9hFmxVZ2fQd
    attoparsec-0.14.4-6aADy1PhqXs9BGl4XaO8ak
    auto-update-0.1.6-6CwdukCfrVbGSSZniTc31f base-4.18.2.1
    base16-bytestring-1.0.2.0-1V8pBdgUhcODBkL2Ak8rbg
    base64-bytestring-1.2.1.0-iqsJDsMFf5LUxvwcpGqT9 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-1hYZCYjvuIpIceCeIJyCUg containers-0.6.7
    crypton-1.0.4-BMCJ5g7BmWBFw24KZjiuHQ
    hourglass-0.2.12-BoSZTGBQ5wA13E3fJB5emQ
    iproute-1.7.15-840Tt03kEDkHPRMe40WH2F mtl-2.3.1
    network-3.1.4.0-AiHJr4xbLJq8z0BHBbc6nI
    psqueues-0.2.8.3-248O7188Jo8HtjAqW7k0At

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dns
version:              4.2.0
visibility:           public
id:                   dns-4.2.0-1kiLSsAMceC24x0PD8dqXZ
key:                  dns-4.2.0-1kiLSsAMceC24x0PD8dqXZ
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  8f579222d649acdcf39413eb5bb7cdf0
exposed:              True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils

hidden-modules:       Network.DNS.Transport
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dns-4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.2.0-1kiLSsAMceC24x0PD8dqXZ
depends:
    array-0.5.6.0 async-2.2.5-G9iNhoihA4w9hFmxVZ2fQd
    attoparsec-0.14.4-6aADy1PhqXs9BGl4XaO8ak
    auto-update-0.1.6-6CwdukCfrVbGSSZniTc31f base-4.18.2.1
    base16-bytestring-1.0.2.0-1V8pBdgUhcODBkL2Ak8rbg
    base64-bytestring-1.2.1.0-iqsJDsMFf5LUxvwcpGqT9 bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.4-BMCJ5g7BmWBFw24KZjiuHQ
    dns-4.2.0-A2aNY33DBaa2XhdZBWKfHv-dns-internal
    hourglass-0.2.12-BoSZTGBQ5wA13E3fJB5emQ
    iproute-1.7.15-840Tt03kEDkHPRMe40WH2F mtl-2.3.1
    network-3.1.4.0-AiHJr4xbLJq8z0BHBbc6nI
    psqueues-0.2.8.3-248O7188Jo8HtjAqW7k0At

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

